==> moagg_0.11.orig.tar.gz: moagg-0.11/libMoaggObjects/include/Crates.h <==
#ifndef CRATES_H
#define CRATES_H

#include "Tools.h"
#include "StaticDecorationBase.h"

//----------------------------------------------------------------------------
class CrateSurfaces : public SurfacesBase
{
    SURFACES_SINGLETON_OBJECT(CrateSurfaces);

  public:

    enum Type
    {
        T_SMALL = 0,
        T_MEDIUM = 1,
        T_BIG = 2,
        T_BONUS = 3,
        T_FUEL = 4,
        T_TOTAL_NUMBER = 5
    };

    inline const SDL_Surface *getSurface(Type type) const
    {
        assert(type >= 0);
        assert(type < T_TOTAL_NUMBER);

        return m_crates[type];
    }

  private:

    /// All crate surfaces.
    SDL_Surface *m_crates[T_TOTAL_NUMBER];
};



//----------------------------------------------------------------------------
class Crate : public StaticDecorationBase
{
  public:
    class InitializationData : public StaticDecorationBase::InitializationData
    {
      public:
        InitializationData(const XMLNode *crateNode)
            throw (XMLException);
        ~InitializationData();

        CrateSurfaces::Type type;
        unsigned score;
    };


    //------------------------------------------------------------------------
    virtual ~Crate();

    static Crate *create(const XMLNode *crateNode)
        throw (Exception);

    inline CrateSurfaces::Type getType() const 
    {
        return m_type;
    }

    inline unsigned getScore() const 
    {
        return m_score;
    }

    inline unsigned getMass() const
    {
        switch (m_type)
        {
        case CrateSurfaces::T_SMALL:
        case CrateSurfaces::T_MEDIUM:
        case CrateSurfaces::T_BIG:
            return (m_type+1)*20;
        default:
            return 0;
        }
    }

    //------------------------------------------------------------------------
    void update();

  protected:
    //------------------------------------------------------------------------
    Crate(const InitializationData &init);

  private:
    //------------------------------------------------------------------------
    DECLARE_OBJECT_VISITOR_API();

    CrateSurfaces::Type m_type;
    unsigned m_score;
};

#endif //CRATES_H

==> moagg_0.16.orig.tar.gz: moagg-0.16/libMoaggObjects/include/Crates.h <==
#ifndef CRATES_H
#define CRATES_H

#include "Tools.h"
#include "StaticDecorationBase.h"

//----------------------------------------------------------------------------
class CrateSurfaces : public SurfacesBase
{
    SURFACES_SINGLETON_OBJECT(CrateSurfaces);

  public:

    enum Type
    {
        T_SMALL = 0,
        T_MEDIUM = 1,
        T_BIG = 2,
        T_BONUS = 3,
        T_FUEL = 4,
        T_TOTAL_NUMBER = 5
    };

    inline const SDL_Surface *getSurface(Type type) const
    {
        assert(type >= 0);
        assert(type < T_TOTAL_NUMBER);

        return m_crates[type];
    }

  private:

    /// All crate surfaces.
    SDL_Surface *m_crates[T_TOTAL_NUMBER];
};



//----------------------------------------------------------------------------
class Crate : public StaticDecorationBase
{
  public:
    class InitializationData : public StaticDecorationBase::InitializationData
    {
      public:
        InitializationData(const XMLNode *crateNode);
        ~InitializationData();

        bool hidden;
        CrateSurfaces::Type type;
        unsigned score;
        unsigned amount;
    };


    //------------------------------------------------------------------------
    virtual ~Crate();

    static Crate *create(const XMLNode *crateNode);

    inline CrateSurfaces::Type getType() const 
    {
        return m_type;
    }

    inline unsigned getValue() const 
    {
        return m_value;
    }

    inline unsigned getMass() const
    {
        switch (m_type)
        {
        case CrateSurfaces::T_SMALL:
        case CrateSurfaces::T_MEDIUM:
        case CrateSurfaces::T_BIG:
            return (m_type+1)*20;
        default:
            return 0;
        }
    }

    //------------------------------------------------------------------------
    void update();

  protected:
    //------------------------------------------------------------------------
    Crate(const InitializationData &init);

  private:
    //------------------------------------------------------------------------
    DECLARE_OBJECT_VISITOR_API();

    CrateSurfaces::Type m_type;

    /**
     * The bonus score (if m_type == T_BONUS)
     * or the amount of fuel (if m_type == T_FUEL)
     */
    unsigned m_value;
};

#endif //CRATES_H
